from django import forms
from django_select2.widgets import HeavySelect2Widget, convert_to_js_string_arr

from emissions.models import SoundFile, Episode

from .models import SoundCell, EpisodeCell
from .views import soundfiles, episodes

class SoundFileWidget(HeavySelect2Widget):
    def render_texts(self, selected_choices, choices):
        queryset = SoundFile.objects.filter(id__in=selected_choices)
        def fmt(soundfile):
            return '%s - %s - %s' % (soundfile.episode.emission.title,
                    soundfile.episode.title,
                    soundfile.title or soundfile.id)
        texts = [fmt(soundfile) for soundfile in queryset.select_related()]
        return convert_to_js_string_arr(texts)


class SoundCellForm(forms.ModelForm):
    class Meta:
        model = SoundCell
        fields = ('soundfile',)

    def __init__(self, *args, **kwargs):
        super(SoundCellForm, self).__init__(*args, **kwargs)
        self.fields['soundfile'].widget = SoundFileWidget(data_view=soundfiles)


class EpisodeWidget(HeavySelect2Widget):
    def render_texts(self, selected_choices, choices):
        queryset = Episode.objects.filter(id__in=selected_choices)
        def fmt(episode):
            return '%s - %s' % (episode.emission.title, episode.title)
        texts = [fmt(episode) for episode in queryset.select_related()]
        return convert_to_js_string_arr(texts)


class EpisodeCellForm(forms.ModelForm):
    class Meta:
        model = EpisodeCell
        fields = ('episode', )

    def __init__(self, *args, **kwargs):
        super(EpisodeCellForm, self).__init__(*args, **kwargs)
        self.fields['episode'].widget = EpisodeWidget(data_view=episodes)
