from django import template
from django.db import models
from django.utils.translation import ugettext_lazy as _

from combo.data.models import CellBase
from combo.data.library import register_cell_class

@register_cell_class
class SoundCell(CellBase):
    soundfile = models.ForeignKey('emissions.SoundFile', null=True)

    class Meta:
        verbose_name = _('Sound')

    def render(self, context):
        tmpl = template.loader.get_template('panikombo/audio.html')
        context['soundfile'] = self.soundfile
        return tmpl.render(context)

    def get_default_form_class(self):
        from .forms import SoundCellForm
        return SoundCellForm

    def get_additional_label(self):
        if self.soundfile:
            if self.soundfile.fragment:
                return u'%s - %s - %s' % (
                        self.soundfile.episode.emission.title,
                        self.soundfile.episode.title,
                        self.soundfile.title)
            else:
                return u'%s - %s' % (
                        self.soundfile.episode.emission.title,
                        self.soundfile.episode.title)

        return ''


@register_cell_class
class EpisodeCell(CellBase):
    episode = models.ForeignKey('emissions.Episode', null=True)

    class Meta:
        verbose_name = _('Episode')

    def render(self, context):
        tmpl = template.loader.get_template('panikombo/episode.html')
        context['episode'] = self.episode
        context['soundfile'] = self.episode.main_sound
        return tmpl.render(context)

    def get_default_form_class(self):
        from .forms import EpisodeCellForm
        return EpisodeCellForm

    def get_additional_label(self):
        if self.episode:
            return u'%s - %s' % (
                        self.episode.emission.title,
                        self.episode.title)
        return ''
